@@ -52,11 +52,22 @@ WS_DLL_PUBLIC
 void
 wmem_strbuf_append(wmem_strbuf_t *strbuf, const gchar *str);
 
+/* Appends up to append_len bytes (as allowed by strbuf->max_len) from
+ * str. Ensures that strbuf is null terminated afterwards but will copy
+ * embedded nulls. */
+WS_DLL_PUBLIC
+void
+wmem_strbuf_append_len(wmem_strbuf_t *strbuf, const gchar *str, gsize append_len);
+
 WS_DLL_PUBLIC
 void
 wmem_strbuf_append_printf(wmem_strbuf_t *strbuf, const gchar *format, ...)
 G_GNUC_PRINTF(2, 3);
 
+WS_DLL_PUBLIC
+void
+wmem_strbuf_append_vprintf(wmem_strbuf_t *strbuf, const gchar *fmt, va_list ap);
+
 WS_DLL_PUBLIC
 void
 wmem_strbuf_append_c(wmem_strbuf_t *strbuf, const gchar c);
@@ -96,7 +107,7 @@ wmem_strbuf_finalize(wmem_strbuf_t *strbuf);
 #endif /* __WMEM_STRBUF_H__ */
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
